%define port          GTK
%define tarname       wxPython-src

%define api           3.0
%define libname       %mklibname %{name} %{api}

%define wxgtku_ver    3.0.2

%define gtkver        2
%define py_setup_args WX_CONFIG=%{_bindir}/wx-config-3.0 WXPORT=gtk%{gtkver}

Summary:        Cross platform GUI toolkit for Python using wx%{port}
Name:           wxPython
Version:		3.0.2.0
Release:        %mkrel 2
License:        LGPLv2+ and wxWidgets
Group:          Development/Python
URL:            http://wxPython.org/
Source0:        http://downloads.sourceforge.net/wxpython/%{tarname}-%{version}.tar.xz
Patch0:         wxPython-3.0.0.0-literal.patch
Patch1:         wxPython-3.0.2.0-getxwindowcrash.patch
Patch2:         wxPython-3.0.2.0-plot.patch
BuildRequires:  wxgtk3.0-devel >= %{wxgtku_ver}
BuildRequires:  imagemagick
BuildRequires:  pkgconfig(python2)
%if %{gtkver} == 3
BuildRequires:  pkgconfig(gtk+-3.0)
%endif
%if %{gtkver} == 2
BuildRequires:  pkgconfig(gtk+-2.0)
%endif

Provides:       wxwin
Obsoletes:		wxPythonGTK
Provides:       wxPythonGTK = %{version}-%{release}
Requires:       %{name}-wxversion = %{version}-%{release}

%description
wxPython is a GUI toolkit for Python that is a wrapper around the
wxWindows C++ GUI library.  wxPython provides a large variety of
window types and controls, all implemented with a native look and feel
(and native runtime speed) on the platforms it is supported on.

This package is implemented using the %{port} port of wxWindows.

%package        wxversion
Summary:        Select a specific version of %{name}
Group:          Development/Python
Obsoletes:		wxPythonGTK-wxversion
Provides:		wxPythonGTK-wxversion = %version-%release

%description    wxversion
wxPython is a GUI toolkit for Python that is a wrapper around the
wxWindows C++ GUI library.  wxPython provides a large variety of
window types and controls, all implemented with a native look and feel
(and native runtime speed) on the platforms it is supported on.

This package contains the wxversion python module needed if several versions of
wxPython are installed.

%package        tools
Summary:        Example applications from %{name}
Group:          Development/Python
Obsoletes:		wxPythonGTK-tools
Provides:		wxPythonGTK-tools = %version-%release
Requires:       %{name} = %{version}-%{release}

%description    tools
wxPython is a GUI toolkit for Python that is a wrapper around the
wxWindows C++ GUI library.  wxPython provides a large variety of
window types and controls, all implemented with a native look and feel
(and native runtime speed) on the platforms it is supported on.

This contains the example applications that come with wxPython like
PyShell and XRCed.

%package -n     %libname-devel
Summary:        Development files of %{name}
Group:          Development/Python
Provides:       libwxPython-devel = %{version}-%{release}
Obsoletes:		wxPythonGTK-devel
Provides:		wxPythonGTK-devel = %version-%release
Provides:       libwxPythonGTK-devel = %{version}-%{release}
Requires:       %{name} = %{version}-%{release}
Requires:       wxgtk-devel >= %{wxgtku_ver}

%description -n %libname-devel
This packages contains the headers and etc. for building apps or
Python extension modules that use the same wx%{port} shared libraries
that wxPython uses.

%package        docs
Group:          Documentation
Summary:        Documentation and samples for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    docs
Documentation, samples and demo application for wxPython.

%prep
%setup -q -n %{tarname}-%{version}/wxPython
%apply_patches

# fix libdir otherwise additional wx libs cannot be found
sed -i -e 's|/usr/lib|%{_libdir}|' -e 's|-O3|-O2|' config.py

%build
# (Fedora) included distutils is not multilib aware; use normal
rm -rf distutils
%py2_build

%install
%py2_install

# install Mageia menu items
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-pyshell.desktop << EOF
[Desktop Entry]
Name=PyShell
Comment=GUI Python Shell
Exec=%{_bindir}/pyshell %U
Icon=PyCrust
Terminal=false
Type=Application
StartupNotify=true
Categories=GNOME;GTK;Development;
EOF

cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-pycrust.desktop << EOF
[Desktop Entry]
Name=PyCrust
Comment=GUI Python Shell with Filling
Exec=%{_bindir}/pycrust %U
Icon=PyCrust
Terminal=false
Type=Application
StartupNotify=true
Categories=GNOME;GTK;Development;
EOF

cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-pyalamode.desktop << EOF
[Desktop Entry]
Name=PyAlaMode
Comment=GUI Python Shell with Filling and Editor Windows
Exec=%{_bindir}/pyalamode %U
Icon=PyCrust
Terminal=false
Type=Application
StartupNotify=true
Categories=GNOME;GTK;Development;
EOF

cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-xrced.desktop << EOF
[Desktop Entry]
Name=XRCed
Comment=XRC resource editor for wxPython
Exec=%{_bindir}/xrced %U
Icon=XRCed
Terminal=false
Type=Application
StartupNotify=true
Categories=GNOME;GTK;Development;
EOF

cat > %{buildroot}%{_datadir}/applications/%{_real_vendor}-editra.desktop << EOF
[Desktop Entry]
Name=Editra
Comment="Programmer's Text Editor"
Exec=/usr/bin/editra
Icon=editra
Terminal=false
Type=Application
Categories=GNOME;GTK;Development;
StartupNotify=true
EOF

#icons
#cd wxPython
mkdir -p %{buildroot}%{_miconsdir}
install -m 644 wx/py/PyCrust_16.png %{buildroot}%{_miconsdir}/PyCrust.png
install -m 644 wx/py/PyCrust_32.png %{buildroot}%{_iconsdir}/PyCrust.png
install -m 644 wx/tools/XRCed/XRCed_16.png %{buildroot}%{_miconsdir}/XRCed.png
install -m 644 wx/tools/XRCed/XRCed_32.png %{buildroot}%{_iconsdir}/XRCed.png

mkdir -p %{buildroot}%{_iconsdir}/hicolor/{16x16,32x32,64x64,128x128}/apps
convert -scale 16x16 wx/tools/Editra/pixmaps/editra.png %{buildroot}%{_iconsdir}/hicolor/16x16/apps/editra.png
convert -scale 32x32 wx/tools/Editra/pixmaps/editra.png %{buildroot}%{_iconsdir}/hicolor/32x32/apps/editra.png
convert -scale 64x64 wx/tools/Editra/pixmaps/editra.png %{buildroot}%{_iconsdir}/hicolor/64x64/apps/editra.png
install -m 644 wx/tools/Editra/pixmaps/editra.png %{buildroot}%{_iconsdir}/hicolor/128x128/apps/editra.png

#gw fix paths
%if "%{python2_sitelib}" != "%{python2_sitearch}"
mv %{buildroot}%{python2_sitelib}/* %{buildroot}%{python2_sitearch}
%endif

# don't ship these ones, firstly we have python >= 2.7, and secondly they mess
# with the pythoneggs.py auto-requires generation
%if "%{python2_version}" >= "2.7"
rm -fr %{buildroot}%{python2_sitearch}/wx-%{api}-gtk%{gtkver}/wx/tools/Editra/plugins/{*py2.5.egg,*py2.6.egg}
%endif

%files
%{python2_sitearch}/wx.pth
%{python2_sitearch}/*.egg-info
%dir %{python2_sitearch}/wx-%{api}-gtk%{gtkver}
%{python2_sitearch}/wx-%{api}-gtk%{gtkver}/wx
%{python2_sitearch}/wx-%{api}-gtk%{gtkver}/*.egg-info

%files tools
%{_bindir}/*
%{_datadir}/applications/%{_real_vendor}-*
%{_iconsdir}/*.png
%{_miconsdir}/*.png
%{_iconsdir}/hicolor/*/*/*.png

%files wxversion
%{python2_sitearch}/wxversion*

%files -n %libname-devel
%{_includedir}/wx-%{api}/wx/wxPython

%files docs
%doc docs/*.*
%doc docs/screenshots


%changelog
* Mon Sep 18 2017 bb2 <bb2> - 3.0.2.0-2pclos2017
- rebuild new gcc

* Wed Aug 31 2016 bb <bb> 3.0.2.0-1pclos2016
- update

